@@ -207,9 +207,6 @@ class SwitchGuideStepDependencyEvents(BaseModel):
 
 class SwitchGuideStepDependency(BaseModel):
     """Represents the instance of a step where the state might not be the same as other instances of the same step
-
-    Args:
-        BaseModel (_type_): Helper type for managing validations and serialization of the model
     """
 
     stepId: str
@@ -232,6 +229,9 @@ class SwitchGuideStepDependency(BaseModel):
     """When True, step is expected to run on event trigger and will not be returned to the frontend.
     """
 
+    options: Optional[dict] = {}
+    """Options to be passed to the step driver. Options are unique to each step so consult the Step documentation."""
+
 class SwitchGuideStepOverrides(BaseModel):
     """Represents the simplest view of a step. Useful for maintain overrides for the step without duplicating the data.
 
