@@ -42,8 +42,8 @@ class GuideDefinitionTask(Task):
             self.logger.error("You must call initialize() before using API.")
             return pandas.DataFrame()
 
-        register = sw.pipeline.Automation.register_task(api_inputs, self)
-
+        script_response = sw.pipeline.Automation.register_task(api_inputs, self)
+        _, register = (0, script_response) if type(script_response) is pandas.DataFrame else script_response
         self.logger.info(register)
 
         headers = api_inputs.api_headers.default
@@ -54,7 +54,7 @@ class GuideDefinitionTask(Task):
 
         journey_endpoint = get_journeys_endpoint(api_inputs=api_inputs)
         
-        url = f"{journey_endpoint}/projects/{api_inputs.api_project_id}/definitions/journeys/register"
+        url = f"{journey_endpoint}/projects/{api_inputs.api_project_id}/definitions/register"
         self.logger.info("Sending request: POST %s", url)
 
         response = requests.post(url, json=json_payload, headers=headers)
@@ -68,9 +68,10 @@ class GuideDefinitionTask(Task):
                 'No data returned for this API call. %s', response.request.url)
             return response_status, pandas.DataFrame()
         
-        response_json_data = json.loads(response.text)
-        response_data = pandas.read_json(StringIO(json.dumps(response_json_data['journeyDefinition'])), typ='Series').to_frame().T
-        response_data.rename(columns = {'id':'JourneyDefinitionId'}, inplace = True)
+        response_data = pandas.read_json(StringIO(response.text), typ='Series').to_frame().T
+
+        response_data.rename(columns = {'driverId':'guideDefinitionId'}, inplace = True)
+
         response_data.columns = _column_name_cap(response_data.columns)
 
         return response_status, response_data
